==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/square_dashed_kanban.py <==
from .. import IconBase


class IconSquareDashedKanban(IconBase):
    class_name = "lucide lucide-square-dashed-kanban"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 7v7"
            }
        },
        {
            "path": {
                "d": "M12 7v4"
            }
        },
        {
            "path": {
                "d": "M16 7v9"
            }
        },
        {
            "path": {
                "d": "M5 3a2 2 0 0 0-2 2"
            }
        },
        {
            "path": {
                "d": "M9 3h1"
            }
        },
        {
            "path": {
                "d": "M14 3h1"
            }
        },
        {
            "path": {
                "d": "M19 3a2 2 0 0 1 2 2"
            }
        },
        {
            "path": {
                "d": "M21 9v1"
            }
        },
        {
            "path": {
                "d": "M21 14v1"
            }
        },
        {
            "path": {
                "d": "M21 19a2 2 0 0 1-2 2"
            }
        },
        {
            "path": {
                "d": "M14 21h1"
            }
        },
        {
            "path": {
                "d": "M9 21h1"
            }
        },
        {
            "path": {
                "d": "M5 21a2 2 0 0 1-2-2"
            }
        },
        {
            "path": {
                "d": "M3 14v1"
            }
        },
        {
            "path": {
                "d": "M3 9v1"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/square_dashed_kanban.py <==
from .. import IconBase


class IconSquareDashedKanban(IconBase):
    class_name = "lucide lucide-square-dashed-kanban"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 7v7"
            }
        },
        {
            "path": {
                "d": "M12 7v4"
            }
        },
        {
            "path": {
                "d": "M16 7v9"
            }
        },
        {
            "path": {
                "d": "M5 3a2 2 0 0 0-2 2"
            }
        },
        {
            "path": {
                "d": "M9 3h1"
            }
        },
        {
            "path": {
                "d": "M14 3h1"
            }
        },
        {
            "path": {
                "d": "M19 3a2 2 0 0 1 2 2"
            }
        },
        {
            "path": {
                "d": "M21 9v1"
            }
        },
        {
            "path": {
                "d": "M21 14v1"
            }
        },
        {
            "path": {
                "d": "M21 19a2 2 0 0 1-2 2"
            }
        },
        {
            "path": {
                "d": "M14 21h1"
            }
        },
        {
            "path": {
                "d": "M9 21h1"
            }
        },
        {
            "path": {
                "d": "M5 21a2 2 0 0 1-2-2"
            }
        },
        {
            "path": {
                "d": "M3 14v1"
            }
        },
        {
            "path": {
                "d": "M3 9v1"
            }
        }
    ]
}
